import { Observable, Subject } from 'rxjs';
import { Logger, LogService, ElectronService, ConfigService } from 'terminus-core';
import { SessionOptions, SessionPersistenceProvider } from '../api';
export interface IChildProcess {
    pid: number;
    ppid: number;
    command: string;
}
export declare abstract class BaseSession {
    open: boolean;
    name: string;
    recoveryId: string;
    truePID: number;
    output$: Observable<string>;
    closed$: Observable<void>;
    destroyed$: Observable<void>;
    protected output_: Subject<string>;
    protected closed_: Subject<void>;
    protected destroyed_: Subject<void>;
    private initialDataBuffer;
    private initialDataBufferReleased;
    constructor();
    emitOutput(data: string): void;
    releaseInitialDataBuffer(): void;
    abstract resize(columns: any, rows: any): any;
    abstract write(data: any): any;
    abstract kill(signal?: string): any;
    abstract getChildProcesses(): Promise<IChildProcess[]>;
    abstract gracefullyKillProcess(): Promise<void>;
    abstract getWorkingDirectory(): Promise<string>;
    destroy(): Promise<void>;
}
export declare class Session extends BaseSession {
    private pty;
    constructor(options: SessionOptions);
    resize(columns: any, rows: any): void;
    write(data: any): void;
    kill(signal?: string): void;
    getChildProcesses(): Promise<IChildProcess[]>;
    gracefullyKillProcess(): Promise<void>;
    getWorkingDirectory(): Promise<string>;
}
export declare class SessionsService {
    private persistenceProviders;
    private config;
    sessions: {
        [id: string]: Session;
    };
    logger: Logger;
    private lastID;
    constructor(persistenceProviders: SessionPersistenceProvider[], config: ConfigService, electron: ElectronService, log: LogService);
    prepareNewSession(options: SessionOptions): Promise<SessionOptions>;
    addSession(options: SessionOptions): Session;
    recover(recoveryId: string): Promise<SessionOptions>;
    private getPersistence();
}
